summaryrefslogtreecommitdiff
path: root/proto
diff options
context:
space:
mode:
Diffstat (limited to 'proto')
-rw-r--r--proto/babel/babel.c16
-rw-r--r--proto/babel/babel.h2
-rw-r--r--proto/bfd/bfd.c37
-rw-r--r--proto/bfd/bfd.h4
-rw-r--r--proto/bfd/io.c4
-rw-r--r--proto/bgp/bgp.c36
-rw-r--r--proto/ospf/dbdes.c10
-rw-r--r--proto/ospf/iface.c28
-rw-r--r--proto/ospf/lsupd.c14
-rw-r--r--proto/ospf/neighbor.c26
-rw-r--r--proto/ospf/ospf.c6
-rw-r--r--proto/ospf/ospf.h2
-rw-r--r--proto/ospf/rt.c6
-rw-r--r--proto/radv/radv.c6
-rw-r--r--proto/radv/radv.h2
-rw-r--r--proto/rip/rip.c20
-rw-r--r--proto/rip/rip.h2
-rw-r--r--proto/rpki/rpki.c22
18 files changed, 121 insertions, 122 deletions
diff --git a/proto/babel/babel.c b/proto/babel/babel.c
index 768bbda8..aa7e8b68 100644
--- a/proto/babel/babel.c
+++ b/proto/babel/babel.c
@@ -1433,14 +1433,14 @@ babel_iface_timer(timer *t)
btime next_event = MIN(ifa->next_hello, ifa->next_regular);
if (ifa->want_triggered) next_event = MIN(next_event, ifa->next_triggered);
- tm2_set(ifa->timer, next_event);
+ tm_set(ifa->timer, next_event);
}
static inline void
babel_iface_kick_timer(struct babel_iface *ifa)
{
if (ifa->timer->expires > (current_time() + 100 MS))
- tm2_start(ifa->timer, 100 MS);
+ tm_start(ifa->timer, 100 MS);
}
static void
@@ -1454,7 +1454,7 @@ babel_iface_start(struct babel_iface *ifa)
ifa->next_regular = current_time() + (random() % ifa->cf->update_interval);
ifa->next_triggered = current_time() + MIN(1 S, ifa->cf->update_interval / 2);
ifa->want_triggered = 0; /* We send an immediate update (below) */
- tm2_start(ifa->timer, 100 MS);
+ tm_start(ifa->timer, 100 MS);
ifa->up = 1;
babel_send_hello(ifa);
@@ -1487,7 +1487,7 @@ babel_iface_stop(struct babel_iface *ifa)
}
}
- tm2_stop(ifa->timer);
+ tm_stop(ifa->timer);
ifa->up = 0;
}
@@ -1585,7 +1585,7 @@ babel_add_iface(struct babel_proto *p, struct iface *new, struct babel_iface_con
init_list(&ifa->neigh_list);
ifa->hello_seqno = 1;
- ifa->timer = tm2_new_init(ifa->pool, babel_iface_timer, ifa, 0, 0);
+ ifa->timer = tm_new_init(ifa->pool, babel_iface_timer, ifa, 0, 0);
init_list(&ifa->msg_queue);
ifa->send_event = ev_new(ifa->pool);
@@ -2050,7 +2050,7 @@ static inline void
babel_kick_timer(struct babel_proto *p)
{
if (p->timer->expires > (current_time() + 100 MS))
- tm2_start(p->timer, 100 MS);
+ tm_start(p->timer, 100 MS);
}
@@ -2214,8 +2214,8 @@ babel_start(struct proto *P)
OFFSETOF(struct babel_entry, n), 0, babel_init_entry);
init_list(&p->interfaces);
- p->timer = tm2_new_init(P->pool, babel_timer, p, 1 S, 0);
- tm2_start(p->timer, 1 S);
+ p->timer = tm_new_init(P->pool, babel_timer, p, 1 S, 0);
+ tm_start(p->timer, 1 S);
p->update_seqno = 1;
p->router_id = proto_get_router_id(&cf->c);
diff --git a/proto/babel/babel.h b/proto/babel/babel.h
index da3293ef..1128d261 100644
--- a/proto/babel/babel.h
+++ b/proto/babel/babel.h
@@ -23,7 +23,7 @@
#include "lib/lists.h"
#include "lib/socket.h"
#include "lib/string.h"
-#include "sysdep/unix/timer.h"
+#include "lib/timer.h"
#define EA_BABEL_METRIC EA_CODE(EAP_BABEL, 0)
#define EA_BABEL_ROUTER_ID EA_CODE(EAP_BABEL, 1)
diff --git a/proto/bfd/bfd.h b/proto/bfd/bfd.h
index 203da437..bc4fe969 100644
--- a/proto/bfd/bfd.h
+++ b/proto/bfd/bfd.h
@@ -140,8 +140,8 @@ struct bfd_session
btime last_tx; /* Time of last sent periodic control packet */
btime last_rx; /* Time of last received valid control packet */
- timer2 *tx_timer; /* Periodic control packet timer */
- timer2 *hold_timer; /* Timer for session down detection time */
+ timer *tx_timer; /* Periodic control packet timer */
+ timer *hold_timer; /* Timer for session down detection time */
list request_list; /* List of client requests (struct bfd_request) */
btime last_state_change; /* Time of last state change */
diff --git a/proto/bfd/io.c b/proto/bfd/io.c
index ab846113..b01cbfce 100644
--- a/proto/bfd/io.c
+++ b/proto/bfd/io.c
@@ -477,7 +477,7 @@ static void *
birdloop_main(void *arg)
{
struct birdloop *loop = arg;
- timer2 *t;
+ timer *t;
int rv, timeout;
birdloop_set_current(loop);
@@ -492,7 +492,7 @@ birdloop_main(void *arg)
if (events_waiting(loop))
timeout = 0;
else if (t = timers_first(&loop->time))
- timeout = (tm2_remains(t) TO_MS) + 1;
+ timeout = (tm_remains(t) TO_MS) + 1;
else
timeout = -1;
diff --git a/proto/bgp/bgp.c b/proto/bgp/bgp.c
index df4c240a..f4791215 100644
--- a/proto/bgp/bgp.c
+++ b/proto/bgp/bgp.c
@@ -328,10 +328,10 @@ bgp_start_timer(timer *t, uint value)
/* The randomization procedure is specified in RFC 4271 section 10 */
btime time = value S;
btime randomize = random() % ((time / 4) + 1);
- tm2_start(t, time - randomize);
+ tm_start(t, time - randomize);
}
else
- tm2_stop(t);
+ tm_stop(t);
}
/**
@@ -517,7 +517,7 @@ bgp_conn_enter_established_state(struct bgp_conn *conn)
int peer_gr_ready = peer->gr_aware && !(peer->gr_flags & BGP_GRF_RESTART);
if (p->gr_active_num)
- tm2_stop(p->gr_timer);
+ tm_stop(p->gr_timer);
/* Number of active channels */
int num = 0;
@@ -616,7 +616,7 @@ bgp_conn_enter_close_state(struct bgp_conn *conn)
int os = conn->state;
bgp_conn_set_state(conn, BS_CLOSE);
- tm2_stop(conn->keepalive_timer);
+ tm_stop(conn->keepalive_timer);
conn->sk->rx_hook = NULL;
/* Timeout for CLOSE state, if we cannot send notification soon then we just hangup */
@@ -779,7 +779,7 @@ bgp_send_open(struct bgp_conn *conn)
DBG("BGP: Sending open\n");
conn->sk->rx_hook = bgp_rx;
conn->sk->tx_hook = bgp_tx;
- tm2_stop(conn->connect_timer);
+ tm_stop(conn->connect_timer);
bgp_schedule_packet(conn, NULL, PKT_OPEN);
bgp_conn_set_state(conn, BS_OPENSENT);
bgp_start_timer(conn->hold_timer, conn->bgp->cf->initial_hold_time);
@@ -888,9 +888,9 @@ bgp_setup_conn(struct bgp_proto *p, struct bgp_conn *conn)
conn->last_channel = 0;
conn->last_channel_count = 0;
- conn->connect_timer = tm2_new_init(p->p.pool, bgp_connect_timeout, conn, 0, 0);
- conn->hold_timer = tm2_new_init(p->p.pool, bgp_hold_timeout, conn, 0, 0);
- conn->keepalive_timer = tm2_new_init(p->p.pool, bgp_keepalive_timeout, conn, 0, 0);
+ conn->connect_timer = tm_new_init(p->p.pool, bgp_connect_timeout, conn, 0, 0);
+ conn->hold_timer = tm_new_init(p->p.pool, bgp_hold_timeout, conn, 0, 0);
+ conn->keepalive_timer = tm_new_init(p->p.pool, bgp_keepalive_timeout, conn, 0, 0);
conn->tx_ev = ev_new(p->p.pool);
conn->tx_ev->hook = bgp_kick_tx;
@@ -1303,8 +1303,8 @@ bgp_start(struct proto *P)
p->event->hook = bgp_decision;
p->event->data = p;
- p->startup_timer = tm2_new_init(p->p.pool, bgp_startup_timeout, p, 0, 0);
- p->gr_timer = tm2_new_init(p->p.pool, bgp_graceful_restart_timeout, p, 0, 0);
+ p->startup_timer = tm_new_init(p->p.pool, bgp_startup_timeout, p, 0, 0);
+ p->gr_timer = tm_new_init(p->p.pool, bgp_graceful_restart_timeout, p, 0, 0);
p->local_id = proto_get_router_id(P->cf);
if (p->rr_client)
@@ -2004,18 +2004,18 @@ bgp_show_proto_info(struct proto *P)
struct bgp_conn *oc = &p->outgoing_conn;
if ((p->start_state < BSS_CONNECT) &&
- (tm2_active(p->startup_timer)))
+ (tm_active(p->startup_timer)))
cli_msg(-1006, " Error wait: %t/%u",
- tm2_remains(p->startup_timer), p->startup_delay);
+ tm_remains(p->startup_timer), p->startup_delay);
if ((oc->state == BS_ACTIVE) &&
- (tm2_active(oc->connect_timer)))
+ (tm_active(oc->connect_timer)))
cli_msg(-1006, " Connect delay: %t/%u",
- tm2_remains(oc->connect_timer), p->cf->connect_delay_time);
+ tm_remains(oc->connect_timer), p->cf->connect_delay_time);
- if (p->gr_active_num && tm2_active(p->gr_timer))
+ if (p->gr_active_num && tm_active(p->gr_timer))
cli_msg(-1006, " Restart timer: %t/-",
- tm2_remains(p->gr_timer));
+ tm_remains(p->gr_timer));
}
else if (P->proto_state == PS_UP)
{
@@ -2037,9 +2037,9 @@ bgp_show_proto_info(struct proto *P)
*/
cli_msg(-1006, " Source address: %I", p->source_addr);
cli_msg(-1006, " Hold timer: %t/%u",
- tm2_remains(p->conn->hold_timer), p->conn->hold_time);
+ tm_remains(p->conn->hold_timer), p->conn->hold_time);
cli_msg(-1006, " Keepalive timer: %t/%u",
- tm2_remains(p->conn->keepalive_timer), p->conn->keepalive_time);
+ tm_remains(p->conn->keepalive_timer), p->conn->keepalive_time);
}
if ((p->last_error_class != BE_NONE) &&
diff --git a/proto/ospf/dbdes.c b/proto/ospf/dbdes.c
index 270259a7..f211935f 100644
--- a/proto/ospf/dbdes.c
+++ b/proto/ospf/dbdes.c
@@ -279,8 +279,8 @@ ospf_process_dbdes(struct ospf_proto *p, struct ospf_packet *pkt, struct ospf_ne
req->lsa = lsa;
req->lsa_body = LSA_BODY_DUMMY;
- if (!tm2_active(n->lsrq_timer))
- tm2_start(n->lsrq_timer, 0);
+ if (!tm_active(n->lsrq_timer))
+ tm_start(n->lsrq_timer, 0);
}
}
@@ -366,7 +366,7 @@ ospf_receive_dbdes(struct ospf_packet *pkt, struct ospf_iface *ifa,
n->options = rcv_options;
n->myimms &= ~DBDES_MS;
n->imms = rcv_imms;
- tm2_stop(n->dbdes_timer);
+ tm_stop(n->dbdes_timer);
ospf_neigh_sm(n, INM_NEGDONE);
ospf_send_dbdes(p, n);
break;
@@ -422,13 +422,13 @@ ospf_receive_dbdes(struct ospf_packet *pkt, struct ospf_iface *ifa,
if (!(n->myimms & DBDES_M) && !(n->imms & DBDES_M))
{
- tm2_stop(n->dbdes_timer);
+ tm_stop(n->dbdes_timer);
ospf_neigh_sm(n, INM_EXDONE);
break;
}
ospf_send_dbdes(p, n);
- tm2_start(n->dbdes_timer, n->ifa->rxmtint S);
+ tm_start(n->dbdes_timer, n->ifa->rxmtint S);
}
else
{
diff --git a/proto/ospf/iface.c b/proto/ospf/iface.c
index 33ec21fb..29d21a07 100644
--- a/proto/ospf/iface.c
+++ b/proto/ospf/iface.c
@@ -263,13 +263,13 @@ ospf_iface_down(struct ospf_iface *ifa)
ospf_neigh_sm(n, INM_KILLNBR);
if (ifa->hello_timer)
- tm2_stop(ifa->hello_timer);
+ tm_stop(ifa->hello_timer);
if (ifa->poll_timer)
- tm2_stop(ifa->poll_timer);
+ tm_stop(ifa->poll_timer);
if (ifa->wait_timer)
- tm2_stop(ifa->wait_timer);
+ tm_stop(ifa->wait_timer);
ospf_flush2_lsa(p, &ifa->link_lsa);
ospf_flush2_lsa(p, &ifa->net_lsa);
@@ -396,15 +396,15 @@ ospf_iface_sm(struct ospf_iface *ifa, int event)
{
ospf_iface_chstate(ifa, OSPF_IS_WAITING);
if (ifa->wait_timer)
- tm2_start(ifa->wait_timer, ifa->waitint S);
+ tm_start(ifa->wait_timer, ifa->waitint S);
}
}
if (ifa->hello_timer)
- tm2_start(ifa->hello_timer, ifa->helloint S);
+ tm_start(ifa->hello_timer, ifa->helloint S);
if (ifa->poll_timer)
- tm2_start(ifa->poll_timer, ifa->pollint S);
+ tm_start(ifa->poll_timer, ifa->pollint S);
ospf_send_hello(ifa, OHS_HELLO, NULL);
}
@@ -494,13 +494,13 @@ ospf_iface_add(struct object_lock *lock)
if (! ifa->stub)
{
- ifa->hello_timer = tm2_new_init(ifa->pool, hello_timer_hook, ifa, ifa->helloint S, 0);
+ ifa->hello_timer = tm_new_init(ifa->pool, hello_timer_hook, ifa, ifa->helloint S, 0);
if (ifa->type == OSPF_IT_NBMA)
- ifa->poll_timer = tm2_new_init(ifa->pool, poll_timer_hook, ifa, ifa->pollint S, 0);
+ ifa->poll_timer = tm_new_init(ifa->pool, poll_timer_hook, ifa, ifa->pollint S, 0);
if ((ifa->type == OSPF_IT_BCAST) || (ifa->type == OSPF_IT_NBMA))
- ifa->wait_timer = tm2_new_init(ifa->pool, wait_timer_hook, ifa, 0, 0);
+ ifa->wait_timer = tm_new_init(ifa->pool, wait_timer_hook, ifa, 0, 0);
ifa->flood_queue_size = ifa_flood_queue_size(ifa);
ifa->flood_queue = mb_allocz(ifa->pool, ifa->flood_queue_size * sizeof(void *));
@@ -703,7 +703,7 @@ ospf_iface_new_vlink(struct ospf_proto *p, struct ospf_iface_patt *ip)
add_tail(&p->iface_list, NODE ifa);
- ifa->hello_timer = tm2_new_init(ifa->pool, hello_timer_hook, ifa, ifa->helloint S, 0);
+ ifa->hello_timer = tm_new_init(ifa->pool, hello_timer_hook, ifa, ifa->helloint S, 0);
ifa->flood_queue_size = ifa_flood_queue_size(ifa);
ifa->flood_queue = mb_allocz(ifa->pool, ifa->flood_queue_size * sizeof(void *));
@@ -717,8 +717,8 @@ ospf_iface_change_timer(timer *tm, uint val)
tm->recurrent = val S;
- if (tm2_active(tm))
- tm2_start(tm, val S);
+ if (tm_active(tm))
+ tm_start(tm, val S);
}
static inline void
@@ -801,8 +801,8 @@ ospf_iface_reconfigure(struct ospf_iface *ifa, struct ospf_iface_patt *new)
ifname, ifa->waitint, new->waitint);
ifa->waitint = new->waitint;
- if (ifa->wait_timer && tm2_active(ifa->wait_timer))
- tm2_start(ifa->wait_timer, ifa->waitint S);
+ if (ifa->wait_timer && tm_active(ifa->wait_timer))
+ tm_start(ifa->wait_timer, ifa->waitint S);
}
/* DEAD TIMER */
diff --git a/proto/ospf/lsupd.c b/proto/ospf/lsupd.c
index 18811392..a98c9098 100644
--- a/proto/ospf/lsupd.c
+++ b/proto/ospf/lsupd.c
@@ -115,7 +115,7 @@ ospf_lsa_lsrq_down(struct top_hash_entry *req, struct ospf_neighbor *n)
if (EMPTY_SLIST(n->lsrql))
{
- tm2_stop(n->lsrq_timer);
+ tm_stop(n->lsrq_timer);
if (n->state == NEIGHBOR_LOADING)
ospf_neigh_sm(n, INM_LOADDONE);
@@ -136,8 +136,8 @@ ospf_lsa_lsrt_up(struct top_hash_entry *en, struct ospf_neighbor *n)
ret->lsa = en->lsa;
ret->lsa_body = LSA_BODY_DUMMY;
- if (!tm2_active(n->lsrt_timer))
- tm2_start(n->lsrt_timer, n->ifa->rxmtint S);
+ if (!tm_active(n->lsrt_timer))
+ tm_start(n->lsrt_timer, n->ifa->rxmtint S);
}
void
@@ -150,7 +150,7 @@ ospf_lsa_lsrt_down_(struct top_hash_entry *en, struct ospf_neighbor *n, struct t
ospf_hash_delete(n->lsrth, ret);
if (EMPTY_SLIST(n->lsrtl))
- tm2_stop(n->lsrt_timer);
+ tm_stop(n->lsrt_timer);
}
static inline int
@@ -175,8 +175,8 @@ ospf_add_flushed_to_lsrt(struct ospf_proto *p, struct ospf_neighbor *n)
ospf_lsa_lsrt_up(en, n);
/* If we found any flushed LSA, we send them ASAP */
- if (tm2_active(n->lsrt_timer))
- tm2_start(n->lsrt_timer, 0);
+ if (tm_active(n->lsrt_timer))
+ tm_start(n->lsrt_timer, 0);
}
static int ospf_flood_lsupd(struct ospf_proto *p, struct top_hash_entry **lsa_list, uint lsa_count, uint lsa_min_count, struct ospf_iface *ifa);
@@ -700,7 +700,7 @@ ospf_receive_lsupd(struct ospf_packet *pkt, struct ospf_iface *ifa,
if (!EMPTY_SLIST(n->lsrql) && (n->lsrqi == SHEAD(n->lsrql)))
{
ospf_send_lsreq(p, n);
- tm2_start(n->lsrq_timer, n->ifa->rxmtint S);
+ tm_start(n->lsrq_timer, n->ifa->rxmtint S);
}
return;
diff --git a/proto/ospf/neighbor.c b/proto/ospf/neighbor.c
index 12eb9e84..f2d3505e 100644
--- a/proto/ospf/neighbor.c
+++ b/proto/ospf/neighbor.c
@@ -66,10 +66,10 @@ reset_lists(struct ospf_proto *p, struct ospf_neighbor *n)
ospf_top_free(n->lsrth);
ospf_reset_lsack_queue(n);
- tm2_stop(n->dbdes_timer);
- tm2_stop(n->lsrq_timer);
- tm2_stop(n->lsrt_timer);
- tm2_stop(n->ackd_timer);
+ tm_stop(n->dbdes_timer);
+ tm_stop(n->lsrq_timer);
+ tm_stop(n->lsrt_timer);
+ tm_stop(n->ackd_timer);
init_lists(p, n);
}
@@ -94,11 +94,11 @@ ospf_neighbor_new(struct ospf_iface *ifa)
init_list(&n->ackl[ACKL_DIRECT]);
init_list(&n->ackl[ACKL_DELAY]);
- n->inactim = tm2_new_init(pool, inactivity_timer_hook, n, 0, 0);
- n->dbdes_timer = tm2_new_init(pool, dbdes_timer_hook, n, ifa->rxmtint S, 0);
- n->lsrq_timer = tm2_new_init(pool, lsrq_timer_hook, n, ifa->rxmtint S, 0);
- n->lsrt_timer = tm2_new_init(pool, lsrt_timer_hook, n, ifa->rxmtint S, 0);
- n->ackd_timer = tm2_new_init(pool, ackd_timer_hook, n, ifa->rxmtint S / 2, 0);
+ n->inactim = tm_new_init(pool, inactivity_timer_hook, n, 0, 0);
+ n->dbdes_timer = tm_new_init(pool, dbdes_timer_hook, n, ifa->rxmtint S, 0);
+ n->lsrq_timer = tm_new_init(pool, lsrq_timer_hook, n, ifa->rxmtint S, 0);
+ n->lsrt_timer = tm_new_init(pool, lsrt_timer_hook, n, ifa->rxmtint S, 0);
+ n->ackd_timer = tm_new_init(pool, ackd_timer_hook, n, ifa->rxmtint S / 2, 0);
return (n);
}
@@ -185,8 +185,8 @@ ospf_neigh_chstate(struct ospf_neighbor *n, u8 state)
n->dds++;
n->myimms = DBDES_IMMS;
- tm2_start(n->dbdes_timer, 0);
- tm2_start(n->ackd_timer, ifa->rxmtint S / 2);
+ tm_start(n->dbdes_timer, 0);
+ tm_start(n->ackd_timer, ifa->rxmtint S / 2);
}
if (state > NEIGHBOR_EXSTART)
@@ -231,7 +231,7 @@ ospf_neigh_sm(struct ospf_neighbor *n, int event)
ospf_neigh_chstate(n, NEIGHBOR_INIT);
/* Restart inactivity timer */
- tm2_start(n->inactim, n->ifa->deadint S);
+ tm_start(n->inactim, n->ifa->deadint S);
break;
case INM_2WAYREC:
@@ -664,5 +664,5 @@ ospf_sh_neigh_info(struct ospf_neighbor *n)
cli_msg(-1013, "%-1R\t%3u\t%s/%s\t%7t\t%-10s %-1I",
n->rid, n->priority, ospf_ns_names[n->state], pos,
- tm2_remains(n->inactim), ifa->ifname, n->ip);
+ tm_remains(n->inactim), ifa->ifname, n->ip);
}
diff --git a/proto/ospf/ospf.c b/proto/ospf/ospf.c
index 13f3845b..3ebebdaa 100644
--- a/proto/ospf/ospf.c
+++ b/proto/ospf/ospf.c
@@ -241,8 +241,8 @@ ospf_start(struct proto *P)
p->asbr = c->asbr;
p->ecmp = c->ecmp;
p->tick = c->tick;
- p->disp_timer = tm2_new_init(P->pool, ospf_disp, p, p->tick S, 0);
- tm2_start(p->disp_timer, 100 MS);
+ p->disp_timer = tm_new_init(P->pool, ospf_disp, p, p->tick S, 0);
+ tm_start(p->disp_timer, 100 MS);
p->lsab_size = 256;
p->lsab_used = 0;
p->lsab = mb_alloc(P->pool, p->lsab_size);
@@ -677,7 +677,7 @@ ospf_reconfigure(struct proto *P, struct proto_config *CF)
p->ecmp = new->ecmp;
p->tick = new->tick;
p->disp_timer->recurrent = p->tick S;
- tm2_start(p->disp_timer, 100 MS);
+ tm_start(p->disp_timer, 100 MS);
/* Mark all areas and ifaces */
WALK_LIST(oa, p->area_list)
diff --git a/proto/ospf/ospf.h b/proto/ospf/ospf.h
index d4571bf6..54eeb74c 100644
--- a/proto/ospf/ospf.h
+++ b/proto/ospf/ospf.h
@@ -18,7 +18,7 @@
#include "lib/lists.h"
#include "lib/slists.h"
#include "lib/socket.h"
-#include "sysdep/unix/timer.h"
+#include "lib/timer.h"
#include "lib/resource.h"
#include "nest/protocol.h"
#include "nest/iface.h"
diff --git a/proto/ospf/rt.c b/proto/ospf/rt.c
index 36bf0387..c0fe218a 100644
--- a/proto/ospf/rt.c
+++ b/proto/ospf/rt.c
@@ -1321,7 +1321,7 @@ ospf_rt_abr2(struct ospf_proto *p)
if (translate && (oa->translate != TRANS_ON))
{
if (oa->translate == TRANS_WAIT)
- tm2_stop(oa->translator_timer);
+ tm_stop(oa->translator_timer);
oa->translate = TRANS_ON;
}
@@ -1329,10 +1329,10 @@ ospf_rt_abr2(struct ospf_proto *p)
if (!translate && (oa->translate == TRANS_ON))
{
if (oa->translator_timer == NULL)
- oa->translator_timer = tm2_new_init(p->p.pool, translator_timer_hook, oa, 0, 0);
+ oa->translator_timer = tm_new_init(p->p.pool, translator_timer_hook, oa, 0, 0);
/* Schedule the end of translation */
- tm2_start(oa->translator_timer, oa->ac->transint S);
+ tm_start(oa->translator_timer, oa->ac->transint S);
oa->translate = TRANS_WAIT;
}
}
diff --git a/proto/radv/radv.c b/proto/radv/radv.c
index 415cd1d9..fe371ab4 100644
--- a/proto/radv/radv.c
+++ b/proto/radv/radv.c
@@ -65,7 +65,7 @@ radv_timer(timer *tm)
ifa->initial--;
}
- tm2_start(ifa->timer, t);
+ tm_start(ifa->timer, t);
}
static char* ev_name[] = { NULL, "Init", "Change", "RS" };
@@ -94,7 +94,7 @@ radv_iface_notify(struct radv_iface *ifa, int event)
/* Update timer */
btime t = ifa->last + ifa->cf->min_delay S - current_time();
- tm2_start(ifa->timer, t);
+ tm_start(ifa->timer, t);
}
static void
@@ -150,7 +150,7 @@ radv_iface_new(struct radv_proto *p, struct iface *iface, struct radv_iface_conf
add_tail(&p->iface_list, NODE ifa);
- ifa->timer = tm2_new_init(pool, radv_timer, ifa, 0, 0);
+ ifa->timer = tm_new_init(pool, radv_timer, ifa, 0, 0);
struct object_lock *lock = olock_new(pool);
lock->addr = IPA_NONE;
diff --git a/proto/radv/radv.h b/proto/radv/radv.h
index a4429c60..8324bb67 100644
--- a/proto/radv/radv.h
+++ b/proto/radv/radv.h
@@ -13,7 +13,7 @@
#include "lib/ip.h"
#include "lib/lists.h"
#include "lib/socket.h"
-#include "sysdep/unix/timer.h"
+#include "lib/timer.h"
#include "lib/resource.h"
#include "nest/protocol.h"
#include "nest/iface.h"
diff --git a/proto/rip/rip.c b/proto/rip/rip.c
index 782e6f5c..a3eeaf17 100644
--- a/proto/rip/rip.c
+++ b/proto/rip/rip.c
@@ -509,7 +509,7 @@ rip_iface_start(struct rip_iface *ifa)
ifa->next_regular = current_time() + (random() % ifa->cf->update_time) + 100 MS;
ifa->next_triggered = current_time(); /* Available immediately */
ifa->want_triggered = 1; /* All routes in triggered update */
- tm2_start(ifa->timer, 100 MS);
+ tm_start(ifa->timer, 100 MS);
ifa->up = 1;
if (!ifa->cf->passive)
@@ -529,7 +529,7 @@ rip_iface_stop(struct rip_iface *ifa)
WALK_LIST_FIRST(n, ifa->neigh_list)
rip_remove_neighbor(p, n);
- tm2_stop(ifa->timer);
+ tm_stop(ifa->timer);
ifa->up = 0;
}
@@ -642,7 +642,7 @@ rip_add_iface(struct rip_proto *p, struct iface *iface, struct rip_iface_config
add_tail(&p->iface_list, NODE ifa);
- ifa->timer = tm2_new_init(p->p.pool, rip_iface_timer, ifa, 0, 0);
+ ifa->timer = tm_new_init(p->p.pool, rip_iface_timer, ifa, 0, 0);
struct object_lock *lock = olock_new(p->p.pool);
lock->type = OBJLOCK_UDP;
@@ -897,14 +897,14 @@ rip_timer(timer *t)
next = MIN(next, expires);
}
- tm2_start(p->timer, MAX(next - now_, 100 MS));
+ tm_start(p->timer, MAX(next - now_, 100 MS));
}
static inline void
rip_kick_timer(struct rip_proto *p)
{
if (p->timer->expires > (current_time() + 100 MS))
- tm2_start(p->timer, 100 MS);
+ tm_start(p->timer, 100 MS);
}
/**
@@ -933,7 +933,7 @@ rip_iface_timer(timer *t)
if (ifa->tx_active)
{
if (now_ < (ifa->next_regular + period))
- { tm2_start(ifa->timer, 100 MS); return; }
+ { tm_start(ifa->timer, 100 MS); return; }
/* We are too late, reset is done by rip_send_table() */
log(L_WARN "%s: Too slow update on %s, resetting", p->p.name, ifa->iface->name);
@@ -958,14 +958,14 @@ rip_iface_timer(timer *t)
p->triggered = 0;
}
- tm2_start(ifa->timer, ifa->want_triggered ? (1 S) : (ifa->next_regular - now_));
+ tm_start(ifa->timer, ifa->want_triggered ? (1 S) : (ifa->next_regular - now_));
}
static inline void
rip_iface_kick_timer(struct rip_iface *ifa)
{
if (ifa->timer->expires > (current_time() + 100 MS))
- tm2_start(ifa->timer, 100 MS);
+ tm_start(ifa->timer, 100 MS);
}
static void
@@ -1111,7 +1111,7 @@ rip_start(struct proto *P)
fib_init(&p->rtable, P->pool, cf->rip2 ? NET_IP4 : NET_IP6,
sizeof(struct rip_entry), OFFSETOF(struct rip_entry, n), 0, NULL);
p->rte_slab = sl_new(P->pool, sizeof(struct rip_rte));
- p->timer = tm2_new_init(P->pool, rip_timer, p, 0, 0);
+ p->timer = tm_new_init(P->pool, rip_timer, p, 0, 0);
p->rip2 = cf->rip2;
p->ecmp = cf->ecmp;
@@ -1121,7 +1121,7 @@ rip_start(struct proto *P)
p->log_pkt_tbf = (struct tbf){ .rate = 1, .burst = 5 };
p->log_rte_tbf = (struct tbf){ .rate = 4, .burst = 20 };
- tm2_start(p->timer, MIN(cf->min_timeout_time, cf->max_garbage_time));
+ tm_start(p->timer, MIN(cf->min_timeout_time, cf->max_garbage_time));
return PS_UP;
}
diff --git a/proto/rip/rip.h b/proto/rip/rip.h
index 2371ea31..55696333 100644
--- a/proto/rip/rip.h
+++ b/proto/rip/rip.h
@@ -24,7 +24,7 @@
#include "lib/resource.h"
#include "lib/socket.h"
#include "lib/string.h"
-#include "sysdep/unix/timer.h"
+#include "lib/timer.h"
#define RIP_V1 1
diff --git a/proto/rpki/rpki.c b/proto/rpki/rpki.c
index f17024fe..3145399b 100644
--- a/proto/rpki/rpki.c
+++ b/proto/rpki/rpki.c
@@ -321,7 +321,7 @@ rpki_schedule_next_refresh(struct rpki_cache *cache)
btime t = cache->refresh_interval S;
CACHE_DBG(cache, "after %t s", t);
- tm2_start(cache->refresh_timer, t);
+ tm_start(cache->refresh_timer, t);
}
static void
@@ -330,7 +330,7 @@ rpki_schedule_next_retry(struct rpki_cache *cache)
btime t = cache->retry_interval S;
CACHE_DBG(cache, "after %t s", t);
- tm2_start(cache->retry_timer, t);
+ tm_start(cache->retry_timer, t);
}
static void
@@ -341,28 +341,28 @@ rpki_schedule_next_expire_check(struct rpki_cache *cache)
t = MAX(t, 1 S);
CACHE_DBG(cache, "after %t s", t);
- tm2_start(cache->expire_timer, t);
+ tm_start(cache->expire_timer, t);
}
static void
rpki_stop_refresh_timer_event(struct rpki_cache *cache)
{
CACHE_DBG(cache, "Stop");
- tm2_stop(cache->refresh_timer);
+ tm_stop(cache->refresh_timer);
}
static void
rpki_stop_retry_timer_event(struct rpki_cache *cache)
{
CACHE_DBG(cache, "Stop");
- tm2_stop(cache->retry_timer);
+ tm_stop(cache->retry_timer);
}
static void UNUSED
rpki_stop_expire_timer_event(struct rpki_cache *cache)
{
CACHE_DBG(cache, "Stop");
- tm2_stop(cache->expire_timer);
+ tm_stop(cache->expire_timer);
}
static int
@@ -569,9 +569,9 @@ rpki_init_cache(struct rpki_proto *p, struct rpki_config *cf)
cache->refresh_interval = cf->refresh_interval;
cache->retry_interval = cf->retry_interval;
cache->expire_interval = cf->expire_interval;
- cache->refresh_timer = tm2_new_init(pool, &rpki_refresh_hook, cache, 0, 0);
- cache->retry_timer = tm2_new_init(pool, &rpki_retry_hook, cache, 0, 0);
- cache->expire_timer = tm2_new_init(pool, &rpki_expire_hook, cache, 0, 0);
+ cache->refresh_timer = tm_new_init(pool, &rpki_refresh_hook, cache, 0, 0);
+ cache->retry_timer = tm_new_init(pool, &rpki_retry_hook, cache, 0, 0);
+ cache->expire_timer = tm_new_init(pool, &rpki_expire_hook, cache, 0, 0);
cache->tr_sock = mb_allocz(pool, sizeof(struct rpki_tr_sock));
cache->tr_sock->cache = cache;
@@ -791,8 +791,8 @@ rpki_get_status(struct proto *P, byte *buf)
static void
rpki_show_proto_info_timer(const char *name, uint num, timer *t)
{
- if (tm2_active(t))
- cli_msg(-1006, " %-16s: %t/%u", name, tm2_remains(t), num);
+ if (tm_active(t))
+ cli_msg(-1006, " %-16s: %t/%u", name, tm_remains(t), num);
else
cli_msg(-1006, " %-16s: ---", name);
}
diff --git a/proto/bfd/bfd.c b/proto/bfd/bfd.c
index 8915140d..67ec2270 100644
--- a/proto/bfd/bfd.c
+++ b/proto/bfd/bfd.c
@@ -64,16 +64,15 @@
* ready, the protocol just creates a BFD request like any other protocol.
*
* The protocol uses a new generic event loop (structure &birdloop) from |io.c|,
* which supports sockets, timers and events like the main loop. Timers
* (structure &timer2) are new microsecond based timers, while sockets and
* events are the same. A birdloop is associated with a thread (field @thread)
* in which event hooks are executed. Most functions for setting event sources
* (like sk_start() or tm2_start()) must be called from the context of that
* thread. Birdloop allows to temporarily acquire the context of that thread for
* the main thread by calling birdloop_enter() and then birdloop_leave(), which
* also ensures mutual exclusion with all event hooks. Note that resources
* associated with a birdloop (like timers) should be attached to the
* independent resource pool, detached from the main resource tree.
*
* There are two kinds of interaction between the BFD core (running in the BFD
* thread) and the rest of BFD (running in the main thread). The first kind are
@@ -177,7 +176,7 @@ bfd_session_update_tx_interval(struct bfd_session *s)
return;
/* Set timer relative to last tx_timer event */
- tm2_set(s->tx_timer, s->last_tx + tx_int_l);
+ tm_set(s->tx_timer, s->last_tx + tx_int_l);
}
static void
@@ -191,7 +190,7 @@ bfd_session_update_detection_time(struct bfd_session *s, int kick)
if (!s->last_rx)
return;
- tm2_set(s->hold_timer, s->last_rx + timeout);
+ tm_set(s->hold_timer, s->last_rx + timeout);
}
static void
@@ -212,16 +211,16 @@ bfd_session_control_tx_timer(struct bfd_session *s, int reset)
goto stop;
/* So TX timer should run */
- if (reset || !tm2_active(s->tx_timer))
+ if (reset || !tm_active(s->tx_timer))
{
s->last_tx = 0;
- tm2_start(s->tx_timer, 0);
+ tm_start(s->tx_timer, 0);
}
return;
stop:
- tm2_stop(s->tx_timer);
+ tm_stop(s->tx_timer);
s->last_tx = 0;
}
@@ -380,7 +379,7 @@ bfd_find_session_by_addr(struct bfd_proto *p, ip_addr addr)
}
static void
-bfd_tx_timer_hook(timer2 *t)
+bfd_tx_timer_hook(timer *t)
{
struct bfd_session *s = t->data;
@@ -389,7 +388,7 @@ bfd_tx_timer_hook(timer2 *t)
}
static void
-bfd_hold_timer_hook(timer2 *t)
+bfd_hold_timer_hook(timer *t)
{
bfd_session_timeout(t->data);
}
@@ -433,8 +432,8 @@ bfd_add_session(struct bfd_proto *p, ip_addr addr, ip_addr local, struct iface *
s->passive = ifa->cf->passive;
s->tx_csn = random_u32();
- s->tx_timer = tm2_new_init(p->tpool, bfd_tx_timer_hook, s, 0, 0);
- s->hold_timer = tm2_new_init(p->tpool, bfd_hold_timer_hook, s, 0, 0);
+ s->tx_timer = tm_new_init(p->tpool, bfd_tx_timer_hook, s, 0, 0);
+ s->hold_timer = tm_new_init(p->tpool, bfd_hold_timer_hook, s, 0, 0);
bfd_session_update_tx_interval(s);
bfd_session_control_tx_timer(s, 1);
@@ -64,16 +64,15 @@
*
* The protocol uses a new generic event loop (structure &birdloop) from |io.c|,
- * which supports sockets, timers and events like the main loop. Timers
- * (structure &timer2) are new microsecond based timers, while sockets and
- * events are the same. A birdloop is associated with a thread (field @thread)
- * in which event hooks are executed. Most functions for setting event sources
- * (like sk_start() or tm2_start()) must be called from the context of that
- * thread. Birdloop allows to temporarily acquire the context of that thread for
- * the main thread by calling birdloop_enter() and then birdloop_leave(), which
- * also ensures mutual exclusion with all event hooks. Note that resources
- * associated with a birdloop (like timers) should be attached to the
- * independent resource pool, detached from the main resource tree.
+ * which supports sockets, timers and events like the main loop. A birdloop is
+ * associated with a thread (field @thread) in which event hooks are executed.
+ * Most functions for setting event sources (like sk_start() or tm_start()) must
+ * be called from the context of that thread. Birdloop allows to temporarily
+ * acquire the context of that thread for the main thread by calling
+ * birdloop_enter() and then birdloop_leave(), which also ensures mutual
+ * exclusion with all event hooks. Note that resources associated with a
+ * birdloop (like timers) should be attached to the independent resource pool,
+ * detached from the main resource tree.
*
* There are two kinds of interaction between the BFD core (running in the BFD